==> deepin-update-ui_1.0.12.tar.xz: BUILD/src/dde-update/translations/dde-update_hu.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation>Az ellenőrzés folyamatban, már majdnem kész. Köszönjük a türelmét</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Felkészülés</translation>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation>Néhány hiba ellenőrizve</translation>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation>Ugrás az asztalra</translation>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation>Üdvözöljük, a rendszer sikeresen frissítve</translation>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation>Jelenlegi verzió:</translation>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>View Logs</source>
        <translation>Naplók megtekintése</translation>
    </message>
    <message>
        <source>Updates successful</source>
        <translation>A frissítés sikeres</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation>A számítógépe hamarosan újraindul %1</translation>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>A számítógépe hamarosan leáll %1</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation>Az automatikus újraindítási folyamat meghiúsult. Kérjük próbálja meg manuálisan újraindítani az eszközt.</translation>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation>Az automatikus leállítási folyamat meghiúsult. Kérjük próbálja meg manuálisan újraindítani az eszközt.</translation>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Hide Logs</source>
        <translation>Naplók elrejtése</translation>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>A frissítés sikertelen</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Ismeretlen hiba</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>A biztonsági mentés készítése sikertelen</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>A rendszer biztonsági mentése nem hajtható végre. Ha folytatja a frissítéseket, később nem térhet vissza a régi rendszerre.</translation>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>Nincs elegendő lemezterület. Kérjük tisztítsa meg a lemezt, és próbálja újra. </translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation>Nem sikerült csatlakozni a biztonsági mentési szolgáltatásokhoz. Kérjük ellenőrizze, és próbálja újra.</translation>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation>Nem sikerült csatlakozni a frissítési szolgáltatásokhoz. Kérjük ellenőrizze, és próbálja újra.</translation>
    </message>
    <message>
        <source>Dependency error</source>
        <translation>Függőségi hiba</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>DPKG hiba</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>Biztonsági mentés készítése újra</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Megszakítás</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>Folytassa a frissítést</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Újraindítás</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Leállítás</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation>Ugrás az asztalra</translation>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>Frissítések előkészítése...</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation>A frissítések telepítésekor ne erőltesse a leállítást vagy a kikapcsolást. Ellenkező esetben a rendszer megsérülhet.</translation>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.21.tar.xz: BUILD/src/dde-update/translations/dde-update_hu.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation>Az ellenőrzés folyamatban, már majdnem kész. Köszönjük a türelmét</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Felkészülés</translation>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation>Néhány hiba ellenőrizve</translation>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation>Ugrás az asztalra</translation>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation>Üdvözöljük, a rendszer sikeresen frissítve</translation>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation>Jelenlegi verzió:</translation>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>Updates successful</source>
        <translation>A frissítés sikeres</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation>A számítógépe hamarosan újraindul %1</translation>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>A számítógépe hamarosan leáll %1</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation>Az automatikus újraindítási folyamat meghiúsult. Kérjük próbálja meg manuálisan újraindítani az eszközt.</translation>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation>Az automatikus leállítási folyamat meghiúsult. Kérjük próbálja meg manuálisan újraindítani az eszközt.</translation>
    </message>
    <message>
        <source>View update logs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Export</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The log has been exported to the desktop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Log export failed, please try again</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>A frissítés sikertelen</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Ismeretlen hiba</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>A biztonsági mentés készítése sikertelen</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>A rendszer biztonsági mentése nem hajtható végre. Ha folytatja a frissítéseket, később nem térhet vissza a régi rendszerre.</translation>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>Nincs elegendő lemezterület. Kérjük tisztítsa meg a lemezt, és próbálja újra. </translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation>Nem sikerült csatlakozni a biztonsági mentési szolgáltatásokhoz. Kérjük ellenőrizze, és próbálja újra.</translation>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation>Nem sikerült csatlakozni a frissítési szolgáltatásokhoz. Kérjük ellenőrizze, és próbálja újra.</translation>
    </message>
    <message>
        <source>Dependency error</source>
        <translation>Függőségi hiba</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>DPKG hiba</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>Biztonsági mentés készítése újra</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Megszakítás</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>Folytassa a frissítést</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Újraindítás</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Leállítás</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation>Ugrás az asztalra</translation>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>Frissítések előkészítése...</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation>A frissítések telepítésekor ne erőltesse a leállítást vagy a kikapcsolást. Ellenkező esetben a rendszer megsérülhet.</translation>
    </message>
    <message>
        <source>View update logs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>updatelog</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
